==> db4o-5.0-mono.tar.gz: db4o-5.0/src/test/src/com/db4o/test/types/Stack4.cs <==
/* Copyright (C) 2004 - 2005  db4objects Inc.  http://www.db4o.com

This file is part of the db4o open source object database.

db4o is free software; you can redistribute it and/or modify it under
the terms of version 2 of the GNU General Public License as published
by the Free Software Foundation and as clarified by db4objects' GPL 
interpretation policy, available at
http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
Suite 350, San Mateo, CA 94403, USA.

db4o is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
using System;
using com.db4o.foundation;

namespace com.db4o.test.types {

   public class Stack4 {
      
      public Stack4() : base() {
      }
      internal Collection4 i_compare;
      internal Collection4 i_with;
      
      internal bool push(Object a_compare) {
         if (i_compare == null) {
            i_compare = new Collection4();
         } else {
            Iterator4 i = i_compare.iterator();
            while (i.hasNext()) {
               if (i.next() == a_compare) {
                  return false;
               }
            }
         }
         i_compare.add(a_compare);
         return true;
      }
   }
}

==> db4o-5.5-mono.tar.gz: db4o-5.5/src/test/src/com/db4o/test/types/Stack4.cs <==
/* Copyright (C) 2004 - 2006  db4objects Inc.  http://www.db4o.com

This file is part of the db4o open source object database.

db4o is free software; you can redistribute it and/or modify it under
the terms of version 2 of the GNU General Public License as published
by the Free Software Foundation and as clarified by db4objects' GPL 
interpretation policy, available at
http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
Suite 350, San Mateo, CA 94403, USA.

db4o is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
using System;
using com.db4o.foundation;

namespace com.db4o.test.types {

   public class Stack4 {
      
      public Stack4() : base() {
      }
      internal Collection4 i_compare;
      internal Collection4 i_with;
      
      internal bool Push(Object a_compare) {
         if (i_compare == null) {
            i_compare = new Collection4();
         } else {
            Iterator4 i = i_compare.Iterator();
            while (i.HasNext()) {
               if (i.Next() == a_compare) {
                  return false;
               }
            }
         }
         i_compare.Add(a_compare);
         return true;
      }
   }
}
